# pykalimux
This is a python script by which you can install Kali Nethunter (Kali Linux) in your termux application without rooted phone.

## Download Counter
<p align="left">
<a href="https://github.com/rc-chuah/pykalimux/releases/latest"><img alt="GitHub all releases" src="https://img.shields.io/github/downloads/rc-chuah/pykalimux/total?label=GITHUB%20DOWNLOADS&style=for-the-badge"></a>
<a href="https://pypi.org/project/pykalimux"><img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dm/pykalimux?label=PYPI%20DOWNLOADS&style=for-the-badge"></a>
</p>

## Usage
### How To Use pykalimux
1. Install Dependencies In Termux `pkg update -y && pkg install git python -y`
2. Install pykalimux `pip install git+https://github.com/rc-chuah/pykalimux`
3. Run It On Termux Terminal `pykalimux`
#### Update pykalimux
- Update To The Latest pykalimux Run This Command Again `pip install git+https://github.com/rc-chuah/pykalimux`
### How To Use pykalimux Using PyPI (Python Package Index)
1. Install Dependencies In Termux `pkg update -y && pkg install python -y`
2. Install pykalimux `pip install pykalimux`
3. Run It On Termux Terminal `pykalimux`
#### Update pykalimux Using PyPI (Python Package Index)
- Update To The Latest pykalimux Using PyPI (Python Package Index) `pip install --upgrade pykalimux`
